import * as _backstage_plugin_scaffolder_node from '@backstage/plugin-scaffolder-node';
import * as _backstage_types from '@backstage/types';
import { ScmIntegrationRegistry } from '@backstage/integration';
import { Config } from '@backstage/config';
import * as _backstage_backend_plugin_api from '@backstage/backend-plugin-api';

/**
 * Creates a new action that initializes a git repository of the content in the workspace
 * and publishes it to GitLab.
 *
 * @public
 */
declare function createPublishGitlabAction(options: {
    integrations: ScmIntegrationRegistry;
    config: Config;
}): _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    defaultBranch?: string;
    /** @deprecated in favour of settings.visibility field */
    repoVisibility?: "private" | "internal" | "public";
    sourcePath?: string | boolean;
    skipExisting?: boolean;
    token?: string;
    gitCommitMessage?: string;
    gitAuthorName?: string;
    gitAuthorEmail?: string;
    signCommit?: boolean;
    setUserAsOwner?: boolean;
    /** @deprecated in favour of settings.topics field */
    topics?: string[];
    settings?: {
        path?: string;
        auto_devops_enabled?: boolean;
        ci_config_path?: string;
        description?: string;
        merge_method?: "merge" | "rebase_merge" | "ff";
        squash_option?: "default_off" | "default_on" | "never" | "always";
        topics?: string[];
        visibility?: "private" | "internal" | "public";
        only_allow_merge_if_all_discussions_are_resolved?: boolean;
        only_allow_merge_if_pipeline_succeeds?: boolean;
        allow_merge_on_skipped_pipeline?: boolean;
    };
    branches?: Array<{
        name: string;
        protect?: boolean;
        create?: boolean;
        ref?: string;
    }>;
    projectVariables?: Array<{
        key: string;
        value: string;
        description?: string;
        variable_type?: string;
        protected?: boolean;
        masked?: boolean;
        raw?: boolean;
        environment_scope?: string;
    }>;
}, _backstage_types.JsonObject, "v1">;

/**
 * Creates an `gitlab:group:ensureExists` Scaffolder action.
 *
 * @public
 */
declare const createGitlabGroupEnsureExistsAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    path: (string | {
        name: string;
        slug: string;
    })[];
    repoUrl: string;
    token?: string | undefined;
}, {
    groupId?: number | undefined;
}, "v1">;

/**
 * Gitlab issue types as specified by gitlab api
 *
 * @public
 */
declare enum IssueType {
    ISSUE = "issue",
    INCIDENT = "incident",
    TEST = "test_case",
    TASK = "task"
}
/**
 * Gitlab issue state events for modifications
 *
 * @public
 */
declare enum IssueStateEvent {
    CLOSE = "close",
    REOPEN = "reopen"
}

/**
 * Creates a `gitlab:issues:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabIssueAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    title: string;
    repoUrl: string;
    projectId: number;
    labels?: string | undefined;
    description?: string | undefined;
    weight?: number | undefined;
    token?: string | undefined;
    assignees?: number[] | undefined;
    createdAt?: string | undefined;
    confidential?: boolean | undefined;
    milestoneId?: number | undefined;
    epicId?: number | undefined;
    dueDate?: string | undefined;
    discussionToResolve?: string | undefined;
    issueType?: IssueType | undefined;
    mergeRequestToResolveDiscussionsOf?: number | undefined;
}, {
    issueUrl: string;
    issueId: number;
    issueIid: number;
}, "v1">;

/**
 * Creates a `gitlab:issue:edit` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const editGitlabIssueAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    projectId: number;
    issueIid: number;
    title?: string | undefined;
    labels?: string | undefined;
    description?: string | undefined;
    weight?: number | undefined;
    token?: string | undefined;
    assignees?: number[] | undefined;
    addLabels?: string | undefined;
    confidential?: boolean | undefined;
    milestoneId?: number | undefined;
    removeLabels?: string | undefined;
    stateEvent?: IssueStateEvent | undefined;
    discussionLocked?: boolean | undefined;
    epicId?: number | undefined;
    dueDate?: string | undefined;
    updatedAt?: string | undefined;
    issueType?: IssueType | undefined;
}, {
    state: string;
    title: string;
    projectId: number;
    updatedAt: string;
    issueUrl: string;
    issueId: number;
    issueIid: number;
}, "v1">;

/**
 * Create a new action that creates a gitlab merge request.
 *
 * @public
 */
declare const createPublishGitlabMergeRequestAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    title: string;
    description: string;
    branchName: string;
    targetBranchName?: string;
    sourcePath?: string;
    targetPath?: string;
    token?: string;
    commitAction?: "create" | "delete" | "update" | "skip" | "auto";
    /** @deprecated projectID passed as query parameters in the repoUrl */
    projectid?: string;
    removeSourceBranch?: boolean;
    assignee?: string;
    reviewers?: string[];
    assignReviewersFromApprovalRules?: boolean;
}, _backstage_types.JsonObject, "v1">;

/**
 * Creates a `gitlab:pipeline:trigger` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createTriggerGitlabPipelineAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    branch: string;
    repoUrl: string;
    projectId: number;
    tokenDescription: string;
    token?: string | undefined;
    variables?: Record<string, string> | undefined;
}, {
    pipelineUrl: string;
}, "v1">;

/**
 * Creates a `gitlab:projectAccessToken:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabProjectAccessTokenAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    projectId: string | number;
    name?: string | undefined;
    token?: string | undefined;
    scopes?: string[] | undefined;
    expiresAt?: string | undefined;
    accessLevel?: number | undefined;
}, {
    access_token: string;
}, "v1">;

/**
 * Creates a `gitlab:projectDeployToken:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabProjectDeployTokenAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    name: string;
    scopes: string[];
    repoUrl: string;
    projectId: string | number;
    username?: string | undefined;
    token?: string | undefined;
}, {
    user: string;
    deploy_token: string;
}, "v1">;

/**
 * Creates a `gitlab:projectVariable:create` Scaffolder action.
 *
 * @param options - Templating configuration.
 * @public
 */
declare const createGitlabProjectVariableAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    key: string;
    value: string;
    repoUrl: string;
    projectId: string | number;
    variableType: string;
    raw?: boolean | undefined;
    token?: string | undefined;
    masked?: boolean | undefined;
    environmentScope?: string | undefined;
    variableProtected?: boolean | undefined;
}, any, "v1">;

/**
 * Create a new action that commits into a gitlab repository.
 *
 * @public
 */
declare const createGitlabRepoPushAction: (options: {
    integrations: ScmIntegrationRegistry;
}) => _backstage_plugin_scaffolder_node.TemplateAction<{
    repoUrl: string;
    branchName: string;
    commitMessage: string;
    sourcePath?: string;
    targetPath?: string;
    token?: string;
    commitAction?: "create" | "delete" | "update";
}, _backstage_types.JsonObject, "v1">;

/**
 * @public
 * The GitLab Module for the Scaffolder Backend
 */
declare const gitlabModule: _backstage_backend_plugin_api.BackendFeature;

export { IssueStateEvent, IssueType, createGitlabGroupEnsureExistsAction, createGitlabIssueAction, createGitlabProjectAccessTokenAction, createGitlabProjectDeployTokenAction, createGitlabProjectVariableAction, createGitlabRepoPushAction, createPublishGitlabAction, createPublishGitlabMergeRequestAction, createTriggerGitlabPipelineAction, gitlabModule as default, editGitlabIssueAction };
